@@ -150,9 +150,9 @@ class FireServiceRota(object):
 
         for r in response['incident_responses']:
            if self._user['id'] == r['user_id']:
-              return r['status']
+              return r
 
-        return 'unknown'
+        return None
 
 
     def get_availability(self):
@@ -197,13 +197,13 @@ class FireServiceRota(object):
 
     def update(self, id):
 
-        response = {}
-        avail = self.get_availability()
+        incident_response = {}
+        availability = self.get_availability()
 
         if id:
-            response = self.get_incident_response(id)
+            incident_response = self.get_incident_response(id)
 
-        return ({**avail,**response})
+        return ({**availability,**incident_response})
 
 
     def _request(
